# Diamond

### Examples

#### register container
1. create an container build endpoint by configure and start custom-image-builder-config.yaml in the globus endpoint server
2. run the following command(substitude the relevent text with your config)
```
diamond-hpc register-container --endpoint_id e099b614-c95e-4148-8ed9-6bd4684b92bc --work_path /work/09912/haotianxie/frontera --image_file_name 
openfold --base_image gcyang/openfold:0.1
```
This process may take a long time.

#### submit task via script file
1. create an container build endpoint by start endpoint in the globus endpoint server
2. run the following command(substitude the relevent text with your config)
```
diamond-hpc run-task-from-script --cmd_script /home/hotine/work/Diamond/example/sample_task/openfold_single_node_task --endpoint_id fb1ffeec-aa63-4136-8a49-f3f24608d36f --container_id a20b806c-29a8-44b4-97b6-591434ca9365 --log_path /work/09912/haotianxie/frontera/openfold_demo_single_node.log
```
